@@ -33,8 +33,11 @@ class Client():
         self.__modules = {}
         
         # pull channels from settings file.
-        channel_list = list(Settings().get_setting("channels"))
-        
+        settings = Settings()
+        if settings.has_key("channels"):
+            channel_list = list(settings.get_setting("channels"))
+        else:
+            channel_list = []
         # if channel is set, attempt to add it to the channels list.
         if channel is not None and channel not in channel_list:
             channel_list.append(channel)
@@ -483,14 +486,14 @@ class Client():
                         log.info(f"Loaded custom module `{_file}`")
                         modules.append(f'modules.{filename}')
         
-        # if os.path.exists("bots/modules/"):
-        #     log.debug("Loading custom modules")
-        #     for _file in os.listdir('bots/modules/'):
-        #         if "__" not in _file:
-        #             print ("Found: ", _file)
-        #             filename, ext = os.path.splitext(_file)
-        #             if '.py' in ext:
-        #                 modules.append(f'modules.{filename}')
+        if os.path.exists("bots/twitch/modules/"):
+            log.debug("Loading custom jarvis modules")
+            for _file in os.listdir('bots/twitch/modules/'):
+                if "__" not in _file:
+                    print ("Found: ", _file)
+                    filename, ext = os.path.splitext(_file)
+                    if '.py' in ext:
+                        modules.append(f'bots.twitch.modules.{filename}')
 
         for extension in reversed(modules):
             try:
